@@ -136,7 +136,6 @@ void MainWindow::init()
     connect(m_ui->actionNextPage, SIGNAL(triggered()), this, SLOT(nextPage()));
     connect(m_ui->actionPrevPage, SIGNAL(triggered()), this, SLOT(prevPage()));
 
-    connect(m_ui->actionPanningOn, SIGNAL(triggered()), this, SLOT(toggleSelection()));
     m_ui->actionCopy->setEnabled(false);
     connect(m_ui->actionCopy, SIGNAL(triggered()), this, SLOT(copy()));
 
@@ -391,6 +390,8 @@ void MainWindow::openDocument(const QString &fileName)
 
     if (!QString::compare(ext, EXT_ODP, Qt::CaseInsensitive) ||
             !QString::compare(ext, EXT_PPTX, Qt::CaseInsensitive) ||
+            !QString::compare(ext, EXT_PPS, Qt::CaseInsensitive) ||
+            !QString::compare(ext, EXT_PPSX, Qt::CaseInsensitive) ||
             !QString::compare(ext, EXT_PPT, Qt::CaseInsensitive)) {
         m_type = Presentation;
     } else if (!QString::compare(ext, EXT_ODS, Qt::CaseInsensitive) ||
@@ -399,6 +400,8 @@ void MainWindow::openDocument(const QString &fileName)
         m_type = Spreadsheet;
     } else {
         m_type = Text;
+        // We need to get the page count again after layout rounds.
+        connect(m_doc, SIGNAL(pageSetupChanged()), this, SLOT(updateUI()));
     }
 
     setWindowTitle(QString("%1 - %2").arg(i18n("Office Viewer"), fname));
@@ -900,10 +903,8 @@ void MainWindow::updateActions()
     m_ui->actionZoomLevel->setEnabled(docLoaded);
     m_ui->actionNextPage->setEnabled(docLoaded);
     m_ui->actionPrevPage->setEnabled(docLoaded);
-    m_ui->actionPanningOn->setEnabled(docLoaded);
 }
 
-
 bool MainWindow::eventFilter(QObject *watched, QEvent *event)
 {
     // show buttons in full screen mode if user taps anywhere in the screen
@@ -1020,7 +1021,6 @@ void MainWindow::activeToolChanged(KoCanvasController* canvas, int)
 
     canvas->setProperty("FingerScrollable", true);
     m_ui->actionCopy->setEnabled(newTool == TextTool_ID);
-    m_ui->actionPanningOn->setChecked(newTool == TextTool_ID);
 }
 
 void MainWindow::setShowProgressIndicator(bool visible)
